@@ -33,6 +33,7 @@ from pyxllib.debug.specialist import browser
 
 def excel_addr(n, m) -> str:
     r"""数字索引转excel地址索引
+
     :param n: 行号，可以输入字符串形式的数字
     :param m: 列号，同上可以输入str的数字
     :return:
@@ -110,32 +111,32 @@ class EnchantCell(EnchantBase):
         return celltype == 0 and cell.value is None
 
     @staticmethod
-    def copy_cell_format(cell, new_cell):
+    def copy_cell_format(cell, dst_cell):
         """ 单元格全格式复制，需要事先指定好新旧单元格的物理位置
         参考：https://stackoverflow.com/questions/23332259/copy-cell-style-openpyxl
         """
         from copy import copy
         if cell.has_style:
-            new_cell.font = copy(cell.font)  # 字体
-            new_cell.border = copy(cell.border)  # 表格线
-            new_cell.fill = copy(cell.fill)  # 填充色
-            new_cell.number_format = copy(cell.number_format)  # 数字格式
-            new_cell.protection = copy(cell.protection)  # 保护？
-            new_cell.alignment = copy(cell.alignment)  # 对齐格式
-            # new_cell.style = cell.style
+            dst_cell.font = copy(cell.font)  # 字体
+            dst_cell.border = copy(cell.border)  # 表格线
+            dst_cell.fill = copy(cell.fill)  # 填充色
+            dst_cell.number_format = copy(cell.number_format)  # 数字格式
+            dst_cell.protection = copy(cell.protection)  # 保护？
+            dst_cell.alignment = copy(cell.alignment)  # 对齐格式
+            # dst_cell.style = cell.style
         # if cell.comment:
         # 这个会引发AttributeError。。。
         #       vml = fromstring(self.workbook.vba_archive.read(ws.legacy_drawing))
         #   AttributeError: 'NoneType' object has no attribute 'read'
-        # new_cell.comment = copy(cell.comment)
+        # dst_cell.comment = copy(cell.comment)
         # 就算开了keep_vba可以强制写入了，打开的时候文件可能还是会错
 
     @staticmethod
-    def copy_cell(cell, new_cell):
+    def copy_cell(cell, dst_cell):
         """ 单元格全格式、包括值的整体复制
         """
-        new_cell.value = cell.value
-        cell.copy_cell_format(new_cell)
+        dst_cell.value = cell.value
+        cell.copy_cell_format(dst_cell)
 
     @staticmethod
     def down(cell):
@@ -189,20 +190,22 @@ class EnchantWorksheet(EnchantBase):
         cls._enchant(openpyxl.worksheet.worksheet.Worksheet, names)
 
     @staticmethod
-    def copy_worksheet(_self, target_ws):
+    def copy_worksheet(_self, dst_ws):
         """跨工作薄时复制表格内容的功能
         openpyxl自带的Workbook.copy_worksheet没法跨工作薄复制，很坑
+
+        src_ws.copy_worksheet(dst_ws)
         """
         # 1 取每个单元格的值
         for row in _self:
             for cell in row:
                 try:
-                    cell.copy_cell(target_ws[cell.coordinate])
+                    cell.copy_cell(dst_ws[cell.coordinate])
                 except AttributeError:
                     pass
         # 2 合并单元格的处理
         for rng in _self.merged_cells.ranges:
-            target_ws.merge_cells(rng.ref)
+            dst_ws.merge_cells(rng.ref)
         # 3 其他表格属性的复制
         # 这个从excel读取过来的时候，是不准的，例如D3可能因为关闭时停留窗口的原因误跑到D103
         # dprint(origin_ws.freeze_panes)
@@ -223,7 +226,7 @@ class EnchantWorksheet(EnchantBase):
 
     @staticmethod
     def search(_self, pattern, min_row=None, max_row=None, min_col=None, max_col=None, order=None, direction=0):
-        """查找满足pattern正则表达式的单元格
+        """ 查找满足pattern正则表达式的单元格
 
         :param pattern: 正则匹配式，可以输入re.complier对象
             会将每个单元格的值转成str，然后进行字符串规则search匹配
@@ -426,7 +429,7 @@ class EnchantWorksheet(EnchantBase):
             for i in range(1, ws.max_row + 1):
                 # TODO 这样跳过其实也不太好，有时候可能就是想创建一个空内容的表格
                 for j in range(1, cols + 1):
-                    if not ws.cell(i, 1).isnone():
+                    if not ws.cell(i, j).isnone():
                         break
                 else:  # 如果没有内容，跳过该行
                     continue
@@ -461,7 +464,7 @@ class EnchantWorksheet(EnchantBase):
 
     @staticmethod
     def init_from_latex(ws, content):
-        """ 注意没有取名为from_latex，因为ws是实现创建好的，这里只是能输入latex代码进行初始化而已 """
+        """ 注意没有取名为from_latex，因为ws是事先创建好的，这里只是能输入latex代码进行初始化而已 """
         from openpyxl.styles import Border, Alignment, Side
 
         from pyxllib.text.pupil import grp_bracket
